==> g3dviewer-0.1.1.tar.gz: g3dviewer-0.1.1/src/libmisc/vector.c <==
#include <stdlib.h>
#include <math.h>

#include <GL/gl.h>

#include <g3dviewer_plugin.h>

int g3d_vector_normal(GLfloat ax, GLfloat ay, GLfloat az,
                      GLfloat bx, GLfloat by, GLfloat bz,
                      GLfloat *nx, GLfloat *ny, GLfloat *nz)
{
  *nx = ay * bz - az * by;
  *ny = az * bx - ax * bz;
  *nz = ax * by - ay * bx;

  return EXIT_SUCCESS;
}

double g3d_vector_angle(GLfloat ax, GLfloat ay, GLfloat az, 
                        GLfloat bx, GLfloat by, GLfloat bz)
{
  double rx, ry, cosa;

  rx = sqrt(ax*ax + ay*ay + az*az);
  ry = sqrt(bx*bx + by*by + bz*bz);

  if((rx < 0.000001) || (ry < 0.000001)) return -1;

  cosa = (ax*bx + ay*by + az*bz) / (rx*ry);
  return acos(cosa);
}

int g3d_vector_wrong(GLfloat ax, GLfloat ay, GLfloat az,
                     GLfloat bx, GLfloat by, GLfloat bz)
{
  if(((ax*bx) < 0) && ((ay*by) < 0) && ((az*bz) < 0)) return EXIT_SUCCESS;
  else return EXIT_FAILURE;
}

int g3d_vector_unify(GLfloat *nx, GLfloat *ny, GLfloat *nz)
{
  GLfloat r;

  r = sqrt(*nx * *nx + *ny * *ny + *nz * *nz);
  if(r < 0.000001) return EXIT_FAILURE;
    
  *nx /= r;
  *ny /= r;
  *nz /= r; 
  return EXIT_SUCCESS;
}

int g3d_vector_transform(GLfloat *x, GLfloat *y, GLfloat *z, GLfloat *matrix)
{
	GLfloat vector[4], result[4];
	int i, k;

	vector[0] = *x;
	vector[1] = *y;
	vector[2] = *z;
	vector[3] = 1.0;

	for(i = 0; i < 4; i ++)
	{
		result[i] = 0.0;

		for(k = 0; k < 4; k ++)
		{
			result[i] += matrix[i * 4 + k] * vector[k];
		}
	}

	*x = result[0];
	*y = result[1];
	*z = result[2];

	return EXIT_SUCCESS;
}

==> g3dviewer-0.2.0.tar.gz: g3dviewer-0.2.0/src/libmisc/vector.c <==
#include <stdlib.h>
#include <math.h>

#include <GL/gl.h>

#include <g3dviewer_plugin.h>

int g3d_vector_normal(GLfloat ax, GLfloat ay, GLfloat az,
                      GLfloat bx, GLfloat by, GLfloat bz,
                      GLfloat *nx, GLfloat *ny, GLfloat *nz)
{
  *nx = ay * bz - az * by;
  *ny = az * bx - ax * bz;
  *nz = ax * by - ay * bx;

  return EXIT_SUCCESS;
}

double g3d_vector_angle(GLfloat ax, GLfloat ay, GLfloat az, 
                        GLfloat bx, GLfloat by, GLfloat bz)
{
  double rx, ry, cosa;

  rx = sqrt(ax*ax + ay*ay + az*az);
  ry = sqrt(bx*bx + by*by + bz*bz);

  if((rx < 0.000001) || (ry < 0.000001)) return 180.0;

  cosa = (ax*bx + ay*by + az*bz) / (rx*ry);
  return acos(cosa);
}

int g3d_vector_wrong(GLfloat ax, GLfloat ay, GLfloat az,
                     GLfloat bx, GLfloat by, GLfloat bz)
{
  if(((ax*bx) < 0) && ((ay*by) < 0) && ((az*bz) < 0)) return EXIT_SUCCESS;
  else return EXIT_FAILURE;
}

int g3d_vector_unify(GLfloat *nx, GLfloat *ny, GLfloat *nz)
{
  GLfloat r;

  r = sqrt(*nx * *nx + *ny * *ny + *nz * *nz);
  if(r < 0.000001) return EXIT_FAILURE;
    
  *nx /= r;
  *ny /= r;
  *nz /= r; 
  return EXIT_SUCCESS;
}

int g3d_vector_transform(GLfloat *x, GLfloat *y, GLfloat *z, GLfloat *matrix)
{
	GLfloat vector[4], result[4];
	int i, k;

	vector[0] = *x;
	vector[1] = *y;
	vector[2] = *z;
	vector[3] = 1.0;

	for(i = 0; i < 4; i ++)
	{
		result[i] = 0.0;

		for(k = 0; k < 4; k ++)
		{
			result[i] += matrix[i * 4 + k] * vector[k];
		}
	}

	*x = result[0];
	*y = result[1];
	*z = result[2];

	return EXIT_SUCCESS;
}
